function [g_out gb] = grav_grid(xg,yg,ztop,zbot,xv,yv,zv,rho,buf);
%g=grav_grid(xg,yg,ztop,zbot,xgv,ygv,zgv,rho,buffer)
%modified by jpw march 2021
% Analytical solution 
% to compute the vertical attraction of a rectangular prism. 
% Sides of prism are parallel to x,y,z axes, and z is vertical down.
%
% Input parameters:
% Prisms are define by xg,yg such as those produced by meshgrid
%BE CAREFUL xg and yg MUST be increasing or BAD THINGS HAPPEN!!!!!
%ztop and zbot define top and bottom of layer in grid, positive is into the
%earth
% xv: a vector of x coordinates of observation points
% yv: a vector of y coordinates of observation points
% zv: observation level vecor.
% rho: density of the prism in kg/(m^3).
%buffer (horizontal) around the to reduce edge effect (make it big it is
%only 4 polygons)
% !!!!!ALL DISTANCE parameters in units of km!!!!!!
%!!!!! all x,y grids need to go little ---> big  
%loop through each prism, gprism then loop through each observation point

g_out=zeros(size(xv(:)));

for jj=1:length(xg(1,:))-1;
    for ii=1:length(yg(:,1))-1;
            %calculate the gravity of current prism
            gtmp=gprism_mod(xg(ii,jj),yg(ii,jj),ztop(ii,jj),xg(ii,jj+1),yg(ii+1,jj),zbot(ii,jj),xv(:), yv(:),zv(:), rho);
            %now add to the previous prisms
            g_out=g_out(:)+gtmp(:);

    end
end

%do we want to add a buffer
gb=[];
if buf > 0
    xr=[min(xg(:)) max(xg(:))];
    yr=[min(yg(:)) max(yg(:))];

    %top border
    top_tmp=mean(ztop(1,:));
    bot_tmp=mean(zbot(1,:));
    gb(:,1)=gprism_mod(xr(1),yr(2),top_tmp,xr(2),yr(2)+buf,bot_tmp,xv(:), yv(:),zv(:), rho); 
    
    %bottom border
    top_tmp=mean(ztop(end,:));
    bot_tmp=mean(zbot(end,:));
    gb(:,2)=gprism_mod(xr(1),yr(1)-buf,top_tmp,xr(2),yr(1),bot_tmp,xv(:), yv(:),zv(:), rho); 
    
    %left border
    top_tmp=mean(ztop(end,:));
    bot_tmp=mean(zbot(end,:));
    gb(:,3)=gprism_mod(xr(1)-buf,yr(1)-buf,top_tmp,xr(1),yr(2)+buf,bot_tmp,xv(:), yv(:),zv(:), rho); 
       
    %right border
    top_tmp=mean(ztop(end,:));
    bot_tmp=mean(zbot(end,:));
    gb(:,4)=gprism_mod(xr(2),yr(1)-buf,top_tmp,xr(2)+buf,yr(2)+buf,bot_tmp,xv(:), yv(:),zv(:), rho); 
    
    %add the border to calc    
    g_out=g_out+sum(gb')';


end





end





