function [WB g1 e_out G L z_ad ]=grav_inv2Dtink(xo,yo,zo,g_true,xp,yp,g_in,LB,UB,good,alpha,itn,rhobr,rho2)
%[layerbottom g_out error]=grav_inv2Dtink(xo,yo,zo,g_true,xp,yp,g_in,LB,UB,good,alpha,it,rho_background,rho_poly)
%ALLL UNITS in KM, postive down 
%xo,yo,zo are the observations (vectors)
%g_true the gravity observations 
%xp,yp are the "center locations" of polygon locations of the model, as produced by meshgrid
%will need to subtract 1/2 resolution if xp are produced by meshgrid
%g_in is the gravity of the "known model input", i.e. ice/bedrock when
%doing a bathymetry inversion 
%LB/UB are the lower and upper bounds must be the size of xp
%good are elements of xp,yp used in the inversion (i.e. if doing bathymetry
%no need to invert grounded sites
%alpha is the tinkov smoothing parameter
%it number of iterations to try %
% rho_background,rho_poly are the density of the background and inverted
% polygon (i.e. bedrock and water for a bathymetry inversion)
%uses the method of BLakely
%good are the ice shelf sites 
%OUTPUT
%depth of water layer bottom
%g_out is the final modeled gravity
%error is the error at each iteration 
good=good(:);
good=good';

UB=UB(:);
LB=LB(:);

%create an empty G matrix 
G=zeros(length(xo(:)),length(xp(:)));

%calculate the G_matrix 
%need the resolution
res1=yp(2)-yp(1);

%do check, if resolution is negative things need to be flipped;
if res1 <= 0, return, end

%calculate the G matrix
for kk=good; %loop through every prism in model
    
%original gravity 
g_2a=gprism_mod(xp(kk)-res1/2,yp(kk),LB(kk),xp(kk)+res1/2,yp(kk)+res1,LB(kk)+.1,xo,yo, zo,rho2-rhobr);%water
%modified to calculate the parital derivative 
g_2b=gprism_mod(xp(kk)-res1/2,yp(kk),LB(kk),xp(kk)+res1/2,yp(kk)+res1,LB(kk)+1,xo,yo, zo,rho2-rhobr);%water +1 km
gd=g_2b(:)-g_2a(:); %influence mgal/km

G(:,kk)=gd;
end

%calculate the L matrix (Aster et al., PEIP) 
%Get the problem size. 
 [mg,n]=size(G);

% Setup the L matrix.
L=zeros(n-2,n);
k=1;
[mr mc]=size(xp);
for i=2:mr-1;
for j=2:mc-1;
  M=zeros(mr,mc);
  M(i,j)=-4;
  M(i,j+1)=1;
  M(i,j-1)=1;
  M(i+1,j)=1;
  M(i-1,j)=1;
  L(k,:)=(reshape(M,n,1))';
  k=k+1;
end
end

%only keep locations to be inverted
G=G(:,good);
L=L(:,good);

%intialized the water bottom (WB) polygons as the upper lower bound limit for
%intial iteration plus a small amount 
WB=LB(:)+.02;

%do the inversion 
for it=1:itn;

sprintf(['Iteration: ' num2str(it) ' of ' num2str(itn)])

%calculate the initial model gravity, the prism density is relative to the
%reference background, so for a water layer and bedrock it is a negative
%density (i.e. 920-2500 kg/m^2) resulting in a reduction in gravity when a
%water layer is added
g_in2=grav_grid(xp,yp,reshape(LB,size(xp)),reshape(WB,size(xp)),xo,yo,zo,rho2-rhobr,0);
%add the water layer to ice+bedrock model
g_1=g_in+g_in2;

% calculate the error 
% 
d=g_true-g_1(:);
d=d(:); %make sure its a column

%output the error at each iteration
e_out(it)=sum(abs(d))./length(d);

%construct the A matrix  
dpad=[d; zeros(n-2,1)];
A=[G; alpha*L];

%update the layer thickness
lb=zeros(size(good));
ub=zeros(size(good));
lb=LB(good)-WB(good);
ub=UB(good)-WB(good);

% do the inversion 
z_ad=bvls(A,dpad,double(lb),double(ub),1000);

%up date the water bottom
WB(good)=WB(good)+z_ad;
end
% % 
%calculate the final modeled gravity 
g_in2=grav_grid(xp,yp,reshape(LB,size(xp)),reshape(WB,size(xp)),xo,yo,zo,rho2-rhobr,0); %gravity of the water layer
g1=g_in+g_in2;%final modeled gravity

