%load the data needed 
load tot_bm.mat   %bedmachine v3 for the Totten
load grav_out.mat  %ICECAP gravity data 
load rump.mat %locations of the rumples
load tot_bm_gl.mat %polygon outlining the grounded ice 
load cmap1.mat %a colormap;
load cmap2.mat %a colormap;


%density of ice (kg/m^3)
ice_rho=920;
%density of the bedrock;
br_rho=2500;
%density of seawater
wat_rho=1020;

%regularization paramenter in the gravity inversion 
alpha=50;
%max iterations in the inversion 
max_it=4;
%smoothness parameter for creating surface of initial model error 
smthpar=5;

%make a few more polygons to define areas "near" the grounding line
Pa=polyshape(tot_bm_gl(:,1), tot_bm_gl(:,2));
Pb=polybuffer(Pa,-15);%expand outward by ~15 km
tot_gl_bound2=Pb.Vertices; %

Pb=polybuffer(Pa,-5); %expand outward by ~5 km
tot_gl_bound3=Pb.Vertices;

% put the spatial information of 
xgo=grav_out.x(:);
ygo=grav_out.y(:);
zgo=grav_out.ac(:)/-1000; % convention for inverion is positive is down, all spatial units are in KM 
%the observed gravity
ggo=grav_out.go(:);

res=2;%resolution of the model domain (km)
[xg yg]=meshgrid(2220:res:2330,-1100:res:-950);%make a mesh

%use interpolate bedmachine onto the model grid
sg=interp2(tot_bm.xg, tot_bm.yg, tot_bm.surf,xg*1000,yg*1000); %surface grid 
ig=interp2(tot_bm.xg, tot_bm.yg, tot_bm.ice,xg*1000,yg*1000);%ice thickness gird
bg=interp2(tot_bm.xg, tot_bm.yg, tot_bm.bed,xg*1000,yg*1000);%bed elevation grid

%inputs for the inversion 
icb=(sg-ig)/-1000; %Ice column bottom
ict=(sg)/-1000; %Ice column top

%buffer around the domain edge (km)
buf=3000;
%calculate the gravity of the ice layer at each observation point 
[gi] = grav_grid(xg-res/2,yg-res/2,ict,icb,xgo(:),ygo(:),zgo(:),ice_rho,buf);
%calculate the gravity of the bedrock layer at each observation point 
gc= grav_grid(xg-res/2,yg-res/2,icb,zeros(size(icb))+10,xgo(:),ygo(:),zgo(:),br_rho,buf);

%add the ice and crust gravity effects (this will be the input for the
%inversion)
g_tot=(gi+gc);
g_tot=g_tot-mean(g_tot);
g_tot=g_tot(:);%to make sure it is a column

%calculate the bed elevation for all observations points 
be1=interp2(tot_bm.xg/1000, tot_bm.yg/1000, tot_bm.bed, xgo, ygo);

%determine which points are inside polygones
c2=(inpolygon(xgo, ygo,tot_gl_bound2(:,1), tot_gl_bound2(:,2)));
c3=(inpolygon(xgo, ygo,tot_gl_bound3(:,1), tot_gl_bound3(:,2)));

%gravity calculation need a DC shift. use the subset of observation to shift the calculated grid to same level
%as observations, adhoc but lets use data within 15 km of Groudning line(c2==0) but at least 5 km (c3==1)of the grounding
%line, these points are not floating and far enough away from from the ice shelf to mimimze influence of water layer 
h=find(c2==0 & c3 ==1 &  be1 < -200 & isnan(g_tot)==0 & isnan(ggo)==0);%find the points 
zsft=mean(g_tot(h)-ggo(h));
g_tot=g_tot-zsft;

%now account remaing errors "gravity shift", 
%caclulate the misfit using data > 5 km from grounding line
v1=find((inpolygon(xgo, ygo,tot_gl_bound3(:,1), tot_gl_bound3(:,2))==1));

%calulate the error between the ice+bedrock gravity and observed FA
err1=g_tot(v1)-ggo(v1);

%now compute a smooth version of the error to account for long wavelength features (crust, sedimentary basins);
mfgrid=reshape(gridfit(xgo(v1), ygo(v1),err1,xg(1,:), yg(:,1),'smoothness',smthpar),size(xg));

%calculate the misfit at at each observation point;
mfcorr=interp2(xg,yg,mfgrid,xgo,ygo);

%now subtract this from the modeled gravity to create the post shift
%modeled gravity that takes into account long wavelength features but not
%water layer 
g_tot2=g_tot-mfcorr;
%% 
%find the grid points to be inverted 
%only invert for water thickness under floating ice
good=find(inpolygon(xg(:),yg(:),tot_bm_gl(:,1), tot_bm_gl(:,2))==0 & inpolygon(xg(:), yg(:),rump.xy1(:,1), rump.xy1(:,2))==0 & inpolygon(xg(:), yg(:),rump.xy2(:,1), rump.xy2(:,2))==0 & xg(:) > 2230);

% only use observations near the ice shelf (observations "far" grounding line will not change, this speeds things up), get rid of any lingering
% Nan's very bad for the inversion!
v2=find(c2==0 & xgo > 2240 & xgo < 2300 & ygo < -980 &  isnan(ggo)==0 & isnan(g_tot2)==0 );

%doing a constrained inversion,  
LB=icb  ;%lower bound, water layer top can't be above the ice bottom
UB=zeros(size(LB))+5;%upper bound water layer can't deeper than 5 km

%do the inversion 
if license('test', 'Optimization_Toolbox') ==1 %check to see if the optimization toolbox is available 
    [LB2 go1 eo1 ]=grav_inv2Dtink(xgo(v2),ygo(v2),zgo(v2),ggo(v2),xg-res/2,yg-res/2,g_tot2(v2),LB,UB,good,alpha,max_it,br_rho,wat_rho);
else
    [LB2 go1 eo1 ]=grav_inv2Dtink_noopttoolbox(xgo(v2),ygo(v2),zgo(v2),grav_out.go(v2),xg-res/2,yg-res/2,g_tot2(v2),LB,UB,good,alpha,max_it,br_rho,wat_rho);
end
%% %plot some stuff.

%new esimtate of Bedrock depth in meters & get rid of the bottom few
%rows(edge effects);
BR=reshape(LB2,size(xg))*-1000;%convert to meters
BR(1:5,:)=NaN;

figure, 

ax1(1)=subplot(1,2,1)
imagesc(xg(1,:), yg(:,1),BR );
axis xy
colorbar
xlabel('km'); ylabel('km')
set(gca,'Clim',[-3000 0]);
hold on, plot(tot_bm_gl(:,1),tot_bm_gl(:,2));
axis equal;
title('New Estimate of Bedrock Elevation (m)')

ax1(2)=subplot(1,2,2)
imagesc(xg(1,:), yg(:,1),BR-bg );
axis xy
colormap default;
axis equal
colorbar
set(gca,'Clim',[-500 0]);
hold on, plot(tot_bm_gl(:,1),tot_bm_gl(:,2));
title('Difference between inversion and BedMachine v3 (m)')
linkaxes(ax1,'xy')
xlabel('km'); ylabel('km')

colormap(ax1(1),cmap1);
xlim([2240 2320]);
ylim([-1080 -960]);


% 
% Figure showing processing steps similar to the one in the Supplemental 
%figure;
figure('position',[367   245   502   772])
clear ax2;
ax2(1)=subplot(2,2,1);
scatter(xgo,ygo,10,ggo-g_tot ,'filled');
title([{'Ice-Bedrock Model'} {'Misfit Pre-shift'}])


ax2(2)=subplot(2,2,2);
imagesc(xg(1,:),yg(:,1), mfgrid*-1);
title([{'Gridded'} {'Misfit'}]);

% 
ax2(3)=subplot(2,2,3);
scatter(xgo,ygo, 10,  ggo-g_tot2,'filled');
title([{'Ice-Bedrock Model'} {'Mistfit Post-shift'}])

% 
ax2(4)=subplot(2,2,4);
gotmp=ggo-g_tot2; %observations minus the misfit
gotmp(v2)=ggo(v2)-go1;%the final misfit output at the points used in the inversion
scatter(xgo,ygo, 10,  gotmp,'filled');
title([{'Bathymetry Inversion'} {'Misfist'}])


for nn=[1:4];
axes(ax2(nn));
cptcmap('GMT_polar','ncol',  20)
set(gca,'Clim', [-20 20])
cb=colorbar('Southoutside')
hold on, plot(tot_bm_gl(:,1), tot_bm_gl(:,2),'k','linewidth',2);
xlabel('PS71 Easting (km)')
ylabel('PS71 Northing (km)')
set(gca,'fontsize', 12)
cb.Label.String=('Misfit (mGal)');
cb.FontSize=12
axis xy
end


colormap(cmap2);
linkaxes(ax2,'xy');
xlim([2231 2315]);
ylim([-1060 -960])
